@@ -3,10 +3,10 @@ import getpass
 import ConfigParser
 import json
 import sys
+
 import re
 import os
 from os.path import join, expanduser, abspath, isfile
-
 import yaml
 import tutum
 import docker
@@ -59,6 +59,43 @@ def login():
         sys.exit(EXCEPTION_EXIT_CODE)
 
 
+def verify_auth(args):
+    def _login():
+        username = raw_input("Username: ")
+        password = getpass.getpass()
+        try:
+            user, api_key = auth.get_auth(username, password)
+            if api_key is not None:
+                config = ConfigParser.ConfigParser()
+                config.add_section(AUTH_SECTION)
+                config.set(AUTH_SECTION, USER_OPTION, user)
+                config.set(AUTH_SECTION, APIKEY_OPTION, api_key)
+                with open(join(expanduser('~'), TUTUM_FILE), 'w') as cfgfile:
+                    config.write(cfgfile)
+                return True
+        except tutum.TutumAuthError:
+            return False
+        except Exception as e:
+            print(e, file=sys.stderr)
+            sys.exit(EXCEPTION_EXIT_CODE)
+
+    if args.cmd != 'login':
+        try:
+            tutum.api.http.send_request("GET", "/auth")
+        except tutum.TutumAuthError:
+            print("Not Authorized, Please login:", file=sys.stderr)
+            while True:
+                success = _login()
+                if success:
+                    print("Login succeeded!")
+                    # Update user and apikey for SDK
+                    tutum.user = auth.load_from_file()[0] or os.environ.get('TUTUM_USER', None)
+                    tutum.apikey = auth.load_from_file()[1] or os.environ.get('TUTUM_APIKEY', None)
+                    break
+                else:
+                    print("Not Authorized, Please login:", file=sys.stderr)
+
+
 def build(tag, working_directory, quiet, no_cache):
     try:
         directory = abspath(working_directory)
@@ -135,18 +172,19 @@ def service_logs(identifiers):
 
 def service_ps(quiet=False, status=None):
     try:
-        headers = ["NAME", "UUID", "STATUS", "IMAGE", "DEPLOYED"]
+        headers = ["NAME", "UUID", "STATUS", "#CONTAINERS", "IMAGE", "DEPLOYED", ]
         service_list = tutum.Service.list(state=status)
         data_list = []
         long_uuid_list = []
         for service in service_list:
-            data_list.append([service.unique_name, service.uuid[:8],
+            data_list.append([service.name, service.uuid[:8],
                               utils.add_unicode_symbol_to_state(service.state),
+                              service.current_num_containers,
                               service.image_name,
                               utils.get_humanize_local_datetime_from_utc_datetime_string(service.deployed_datetime)])
             long_uuid_list.append(service.uuid)
         if len(data_list) == 0:
-            data_list.append(["", "", "", "", ""])
+            data_list.append(["", "", "", "", "", ""])
 
         if quiet:
             for uuid in long_uuid_list:
@@ -359,7 +397,7 @@ def container_ps(identifier, quiet=False, status=None):
         elif utils.is_uuid4(identifier):
             containers = tutum.Container.list(uuid=identifier, state=status)
         else:
-            containers = tutum.Container.list(unique_name=identifier, state=status) + \
+            containers = tutum.Container.list(name=identifier, state=status) + \
                          tutum.Container.list(uuid__startswith=identifier, state=status)
 
         data_list = []
@@ -375,7 +413,7 @@ def container_ps(identifier, quiet=False, status=None):
                 ports.append(ports_string)
 
             ports_string = ", ".join(ports)
-            data_list.append([container.unique_name,
+            data_list.append([container.name,
                               container.uuid[:8],
                               utils.add_unicode_symbol_to_state(container.state),
                               container.image_name,
@@ -556,7 +594,7 @@ def image_push(name, public):
             print('Tagging %s as %s ...' % (name, repository))
 
         try:
-            docker_client.tag(name, repository, tag=tag)
+            docker_client.tag(name, repository, tag=tag, force=True)
         except Exception as e:
             print(e, file=sys.stderr)
             sys.exit(EXCEPTION_EXIT_CODE)
